@@ -6,6 +6,8 @@ var credits =
                               ],
         [ "Christian Aigner", "Misc > Draw > Dovetail from 2 Points<br>"
                               ],
+        [ "CVH",              "Misc > Script Examples > Mathematics > FlexPainter<br>"
+                              ],
         [ "Matfie",           "Gear generator library item \"InvoluteSpur\"<br>"
                               ],
         [ "Matthias Melcher", "Drawing box joint lines<br>" +
@@ -50,12 +52,33 @@ var credits =
         [ "Weston Schmidt",   "Draw > Dimension > Per-dimension scaling<br>"
                               ],
     ],
+    [
+        qsTr("Hatch Patterns"),
+        [ "John Hyslop",         "BLOCKS-01, BLOCKS-01, " +
+                                 "BOXJOIN-01, BOXJOIN-02, " +
+                                 "BOX-OVERLAP, " +
+                                 "CELTIC-01, CELTIC-02, " +
+                                 "CIRCLES, CIRCLES-02, " +
+                                 "EXPLOSION, " +
+                                 "HEXAGONS, " +
+                                 "HEXJOIN-01, HEXJOIN-02, " +
+                                 "HOLLY, " +
+                                 "LATTICE-01, LATTICE-02, LATTICE-03, " +
+                                 "LATTICE-04, LATTICE-05, LATTICE-06, " +
+                                 "LOOPLINKS, " +
+                                 "MAZE-01, MAZE-02, " +
+                                 "QCAD-LOGO, " +
+                                 "SCAFFOLD, " +
+                                 "SQUIGGLE-01, SQUIGGLE-02, " +
+                                 "TRI-OVERLAP, " +
+                                 "WIRE-FENCE"
+                                 ],
+    ],
     [
         qsTr("Translations"),
-        //[ "Wang Zhen Zhe",     "Chinese (zh_CN) translation." ],
         [ "Petr Zgraja, 'fialot'", "Czech (cs) translation" ],
         [ "Andrew Mustun",       "Dutch (nl) translation" ],
-        [ "Timo Seppola",        "Finnish (fi) translation" ],
+        [ "Timo Seppola, Jarmo", "Finnish (fi) translation" ],
         [ "Andrew Mustun",       "German (de) translation" ],
         [ "Fabrizio Margini",    "Italian (it) translation" ],
         [ "Tanaka Hidemune",     "Japanese (ja) translation and Japanese user reference manual" ],
